@@ -14,7 +14,7 @@ import Haplotype as Haplotype
 import HaplotypeLibrary as HaplotypeLibrary
 import HeuristicGeneProb as HeuristicGeneProb
 import _faker as _faker
-__all__ = ['PyIntersectCompare', 'ped',
-           'hap', 'gen', 'haplib', 'PedigreeHolder', 'Utils', 'Genotype', 'Haplotype', 'Haplotype', 'HaplotypeLibrary', 'HeuristicGeneProb', '_faker']
+# __all__ = ['PyIntersectCompare', 'ped',
+#            'hap', 'gen', 'haplib', 'PedigreeHolder', 'Utils', 'Genotype', 'Haplotype', 'Haplotype', 'HaplotypeLibrary', 'HeuristicGeneProb', '_faker']
 
 
